@@ -1,3 +1,11 @@
+function _aws_cdk_aws_memorydb_CfnUserProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    if (!visitedObjects.has(p.tags))
+        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+    visitedObjects.delete(p);
+}
 function _aws_cdk_aws_memorydb_CfnACLProps(p) {
     if (p == null)
         return;
@@ -14,14 +22,6 @@ function _aws_cdk_aws_memorydb_CfnParameterGroupProps(p) {
         require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
     visitedObjects.delete(p);
 }
-function _aws_cdk_aws_memorydb_CfnUserProps(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    if (!visitedObjects.has(p.tags))
-        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
-    visitedObjects.delete(p);
-}
 function _aws_cdk_aws_memorydb_CfnSubnetGroupProps(p) {
     if (p == null)
         return;
@@ -65,5 +65,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnUser, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty };
+module.exports = { print, _aws_cdk_aws_memorydb_CfnUserProps, _aws_cdk_aws_memorydb_CfnACLProps, _aws_cdk_aws_memorydb_CfnParameterGroupProps, _aws_cdk_aws_memorydb_CfnSubnetGroupProps, _aws_cdk_aws_memorydb_CfnClusterProps, _aws_cdk_aws_memorydb_CfnACL, _aws_cdk_aws_memorydb_CfnParameterGroup, _aws_cdk_aws_memorydb_CfnSubnetGroup, _aws_cdk_aws_memorydb_CfnUser, _aws_cdk_aws_memorydb_CfnCluster, _aws_cdk_aws_memorydb_CfnCluster_EndpointProperty };
 module.exports.DeprecationError = DeprecationError;
